==> nextcloud-30.0.12.tgz: nextcloud/apps/serverinfo/l10n/ru.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информация о ЦП недоступна",
    "CPU Usage:" : "Использование ЦП:",
    "Load average: {percentage} % ({load}) last minute" : "Средняя нагрузка: {percentage} % ({load}) за последнюю минуту",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) за последнюю минуту\n{last5MinutesPercentage} % ({last5Minutes}) за последние 5 минут\n{last15MinutesPercentage} % ({last15Minutes}) за последние 15 минут",
    "RAM Usage:" : "Использование RAM:",
    "SWAP Usage:" : "Использование SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Всего: {memTotalBytes} / Использовано: {memUsageBytes}",
    "RAM info not available" : "RAM информация не доступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Всего: {swapTotalBytes} / Использовано: {swapUsageBytes}",
    "SWAP info not available" : "Информация о SWAP не доступна",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "System" : "Система",
    "Monitoring" : "Мониторинг",
    "Monitoring app with useful server information" : "Приложение мониторинга с полезной информацией о сервере",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Предоставляет полезную информацию о сервере, такую как загрузка процессора, использование ОЗУ, диска, количество пользователей и т.д.",
    "Operating System:" : "Операционная система:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Неизвестный процессор",
    "Memory:" : "Память:",
    "Server time:" : "Серверное время:",
    "Uptime:" : "Время работы:",
    "Temperature" : "Температура",
    "Load" : "Нагрузка",
    "Memory" : "Память",
    "Disk" : "Диск",
    "Mount:" : "Метка диска:",
    "Filesystem:" : "Файловая система:",
    "Size:" : "Размер:",
    "Available:" : "Доступно:",
    "Used:" : "Используется:",
    "Files:" : "Файлы:",
    "Storages:" : "Хранилища:",
    "Free Space:" : "Свободно:",
    "Network" : "Сеть",
    "Hostname:" : "Хост:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Статус:",
    "Speed:" : "Скорость:",
    "Duplex:" : "Дуплекс:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активные пользователи",
    "Last hour" : "Последний час",
    "%s%% of all users" : "%s%% всех пользователей",
    "Last 24 Hours" : "Последние 24 часа",
    "Last 7 Days" : "Последние 7 дней",
    "Last 30 Days" : "Последние 30 дней",
    "Shares" : "Общие ресурсы",
    "Users:" : "Пользователей:",
    "Groups:" : "Группы:",
    "Links:" : "Ссылки:",
    "Emails:" : "Письма:",
    "Federated sent:" : "Отправлено в федерацию:",
    "Federated received:" : "Получено из федерации:",
    "Talk conversations:" : "Talk беседы:",
    "PHP" : "PHP",
    "Version:" : "Версия:",
    "Memory limit:" : "Лимит памяти:",
    "Max execution time:" : "Максимальное время выполнения:",
    "Upload max size:" : "Максимальный размер для отправки:",
    "OPcache Revalidate Frequency:" : "Частота повторной проверки OPcache:",
    "Extensions:" : "Расширения:",
    "Unable to list extensions" : "Невозможно перечислить расширения",
    "Show phpinfo" : "Показать информацию о php",
    "Database" : "База данных",
    "Type:" : "Тип:",
    "External monitoring tool" : "Внешний мониторинг",
    "Use this end point to connect an external monitoring tool:" : "Используйте эту конечную точку для подключения внешнего средства мониторинга:",
    "Copy" : "Копировать",
    "Output in JSON" : "Вывод в формате JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Пропустить раздел \"приложения\" (включение раздела \"приложения\" приведет к отправке внешнего запроса в App Store)",
    "Skip server update" : "Пропустить обновление сервера",
    "To use an access token, please generate one then set it using the following command:" : "Чтобы использовать токен доступа, пожалуйста, сгенерируйте его, а затем установите с помощью следующей команды:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Затем передайте токен с заголовком «NC-Token» при запросе указанного выше URL."
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-31.0.9.tgz: nextcloud/apps/serverinfo/l10n/ru.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Информация о ЦП недоступна",
    "CPU Usage:" : "Использование ЦП:",
    "Load average: {percentage} % ({load}) last minute" : "Средняя нагрузка: {percentage} % ({load}) за последнюю минуту",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) за последнюю минуту\n{last5MinutesPercentage} % ({last5Minutes}) за последние 5 минут\n{last15MinutesPercentage} % ({last15Minutes}) за последние 15 минут",
    "RAM Usage:" : "Использование RAM:",
    "SWAP Usage:" : "Использование SWAP:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Всего: {memTotalBytes} / Использовано: {memUsageBytes}",
    "RAM info not available" : "RAM информация не доступна",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Всего: {swapTotalBytes} / Использовано: {swapUsageBytes}",
    "SWAP info not available" : "Информация о SWAP не доступна",
    "Copied!" : "Скопировано!",
    "Not supported!" : "Не поддерживается!",
    "Press ⌘-C to copy." : "Нажмите ⌘-C для копирования. ",
    "Press Ctrl-C to copy." : "Нажмите Ctrl-C для копирования.",
    "System" : "Система",
    "Monitoring" : "Мониторинг",
    "Monitoring app with useful server information" : "Приложение мониторинга с полезной информацией о сервере",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Предоставляет полезную информацию о сервере, такую как загрузка процессора, использование ОЗУ, диска, количество пользователей и т.д.",
    "Operating System:" : "Операционная система:",
    "CPU:" : "CPU:",
    "Memory:" : "Память:",
    "Server time:" : "Серверное время:",
    "Uptime:" : "Время работы:",
    "Temperature" : "Температура",
    "Load" : "Нагрузка",
    "Memory" : "Память",
    "Disk" : "Диск",
    "Mount:" : "Метка диска:",
    "Filesystem:" : "Файловая система:",
    "Size:" : "Размер:",
    "Available:" : "Доступно:",
    "Used:" : "Используется:",
    "Files:" : "Файлы:",
    "Storages:" : "Хранилища:",
    "Free Space:" : "Свободно:",
    "Network" : "Сеть",
    "Hostname:" : "Хост:",
    "Gateway:" : "Шлюз:",
    "Status:" : "Статус:",
    "Speed:" : "Скорость:",
    "Duplex:" : "Дуплекс:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Активные пользователи",
    "Last hour" : "Последний час",
    "%s%% of all users" : "%s%% всех пользователей",
    "Last 24 Hours" : "Последние 24 часа",
    "Last 7 Days" : "Последние 7 дней",
    "Last 30 Days" : "Последние 30 дней",
    "Shares" : "Общие ресурсы",
    "Users:" : "Пользователей:",
    "Groups:" : "Группы:",
    "Links:" : "Ссылки:",
    "Emails:" : "Письма:",
    "Federated sent:" : "Отправлено в федерацию:",
    "Federated received:" : "Получено из федерации:",
    "Talk conversations:" : "Talk беседы:",
    "PHP" : "PHP",
    "Version:" : "Версия:",
    "Memory limit:" : "Лимит памяти:",
    "Max execution time:" : "Максимальное время выполнения:",
    "Upload max size:" : "Максимальный размер для отправки:",
    "OPcache Revalidate Frequency:" : "Частота повторной проверки OPcache:",
    "Extensions:" : "Расширения:",
    "Unable to list extensions" : "Невозможно перечислить расширения",
    "Show phpinfo" : "Показать информацию о php",
    "Database" : "База данных",
    "Type:" : "Тип:",
    "External monitoring tool" : "Внешний мониторинг",
    "Use this end point to connect an external monitoring tool:" : "Используйте эту конечную точку для подключения внешнего средства мониторинга:",
    "Copy" : "Копировать",
    "Output in JSON" : "Вывод в формате JSON",
    "Skip apps section (including apps section will send an external request to the app store)" : "Пропустить раздел \"приложения\" (включение раздела \"приложения\" приведет к отправке внешнего запроса в App Store)",
    "Skip server update" : "Пропустить обновление сервера",
    "To use an access token, please generate one then set it using the following command:" : "Чтобы использовать токен доступа, пожалуйста, сгенерируйте его, а затем установите с помощью следующей команды:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Затем передайте токен с заголовком «NC-Token» при запросе указанного выше URL.",
    "Unknown Processor" : "Неизвестный процессор"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
